.. AUTO-GENERATED FILE -- DO NOT EDIT!

transforms
==========

Module: :mod:`transforms`
-------------------------
Inheritance diagram for ``ISLP.transforms``:

.. inheritance-diagram:: ISLP.transforms 
   :parts: 3

.. automodule:: ISLP.transforms

.. currentmodule:: ISLP.transforms

Classes
-------

:class:`BSpline`
~~~~~~~~~~~~~~~~


.. autoclass:: BSpline
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`Interaction`
~~~~~~~~~~~~~~~~~~~~


.. autoclass:: Interaction
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`NaturalSpline`
~~~~~~~~~~~~~~~~~~~~~~


.. autoclass:: NaturalSpline
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`Poly`
~~~~~~~~~~~~~


.. autoclass:: Poly
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__
